fn check_local_signing_readiness(subject: &DoctorSubject) -> DoctorStepExpand description
Step 4 helper: verify whether the local side can actually sign as the key.
fn check_local_signing_readiness(subject: &DoctorSubject) -> DoctorStepStep 4 helper: verify whether the local side can actually sign as the key.